@@ -53,6 +53,7 @@ class MacrobotPipeline(object):
         self.resize_scale = 0.5
         self.numer_of_lanes = None
         self.image_tresholded = None
+        #print (self.image_list)
         self.plate_id = self.image_list[0].rsplit('_', 2)[0]
         self.y_position = 800   # Position for leaves
 
@@ -148,16 +149,20 @@ class MacrobotPipeline(object):
         self.get_features()
         # 8. Predict pathogen.
         self.get_prediction_per_lane(self.plate_id, self.destination_path)
-        # 9. Segment leaves.
+        # 9. Segment leavs.
         self.get_leaves_binary()
 
         self.save_images_for_report()
         self.create_report()
 
+        # Todo refactor self.lanes_roi_minrgb into self.lanes_feature for bgt
+        # final_image_list = [self.image_tresholded , self.image_backlight, self.image_red, self.image_blue,
+        #                     self.image_green, self.image_rgb, self.image_uvs, self.lanes_roi_rgb,self.lanes_roi_binary,
+        #                     self.lanes_roi_minrgb, self.predicted_lanes]
 
-        final_image_list = [self.image_tresholded , self.image_backlight, self.image_red, self.image_blue,
-                            self.image_green, self.image_rgb, self.image_uvs, self.lanes_roi_rgb,self.lanes_roi_binary,
-                            self.lanes_roi_minrgb, self.predicted_lanes]
+        final_image_list = [self.image_tresholded, self.image_backlight, self.image_red, self.image_blue,
+                            self.image_green, self.image_rgb, self.image_uvs, self.lanes_roi_rgb, self.lanes_roi_binary,
+                            self.lanes_feature, self.predicted_lanes]
 
         return self.plate_id, self.numer_of_lanes, final_image_list, self.file_results.name
         #self.process()
\ No newline at end of file
